package mdb;

import java.util.logging.Logger;

import javax.annotation.Resource;
import javax.ejb.ActivationConfigProperty;
import javax.ejb.MessageDriven;
import javax.ejb.MessageDrivenContext;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.TextMessage;

/**
 * Message-Driven Bean implementation class for: MessageBean
 *
 */
@MessageDriven(mappedName = "jms/Topic", activationConfig =  {
	@ActivationConfigProperty(propertyName = "messageSelector", propertyValue = "MsgType = 'TR' OR MsgType = 'ET' OR MsgType = 'PP'")
	, @ActivationConfigProperty(propertyName = "subscriptionDurability", propertyValue = "Durable")
	, @ActivationConfigProperty(propertyName = "clientId", propertyValue = "MyID")
	, @ActivationConfigProperty(propertyName = "subscriptionName", propertyValue = "MySub")
	})
public class MessageBean implements MessageListener {
	static final Logger logger = Logger.getLogger("MessageBean");
    @Resource
    public MessageDrivenContext mdc;
    
    /**
     * Default constructor. 
     */
    public MessageBean() {
        // TODO Auto-generated constructor stub
    }
	
	/**
     * @see MessageListener#onMessage(Message)
     */
    public void onMessage(Message inMessage) {
        // TODO Auto-generated method stub
    	TextMessage msg = null;
        try {
            if (inMessage instanceof TextMessage) {
                msg = (TextMessage) inMessage;
                String type = msg.getStringProperty("MsgType");
                String message = msg.getText();
                String sender = message.substring(0, message.indexOf("#"));
                message = message.substring(message.indexOf("#") + 1);
                System.out.println(sender + " to " + type + " say :" + msg.getText());
            } else {
                System.out.println(
                        "Message of wrong type: "
                        + inMessage.getClass().getName());
            }
        } catch (JMSException e) {
            logger.severe(
                    "MessageBean.onMessage: JMSException: " + e.toString());
            e.printStackTrace();
            mdc.setRollbackOnly();
        } catch (Throwable te) {
            logger.severe("MessageBean.onMessage: Exception: " + te.toString());
            te.printStackTrace();
        }
    }

}
