package sb;

import javax.ejb.Remote;
import javax.ejb.Stateless;
import java.util.logging.Logger;
import javax.ejb.SessionContext;
import javax.jms.ConnectionFactory;
import javax.jms.Connection;
import javax.jms.Topic;
import javax.jms.Session;
import javax.jms.MessageProducer;
import javax.jms.TextMessage;
import javax.jms.JMSException;
import javax.annotation.Resource;
import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;

/**
 * Session Bean implementation class PublisherBean
 */
@Stateless
@Remote({
    PublisherBeanRemote.class
})
public class PublisherBean implements PublisherBeanRemote {
	static final Logger logger = Logger.getLogger("PublisherBean");
    Connection connection = null;
    @Resource(mappedName = "jms/ConnectionFactory")
    private ConnectionFactory connectionFactory;
    @Resource
    private SessionContext sc;
    @Resource(mappedName = "jms/Topic")
    private Topic topic;
    
    /**
     * Default constructor. 
     */
    public PublisherBean() {
        // TODO Auto-generated constructor stub
    }
    
    /**
     * Creates the connection.
     */
    @PostConstruct
    public void makeConnection() {
        try {
            connection = connectionFactory.createConnection();
        } catch (Throwable t) {
            // JMSException could be thrown
            logger.severe(
                    "PublisherBean.makeConnection:" + "Exception: "
                    + t.toString());
        }
    }
    
    public void publishNews(String msgType, String msgText) {
    	Session session = null;
        MessageProducer publisher = null;
        TextMessage message = null;

        try {
            session = connection.createSession(true, 0);
            publisher = session.createProducer(topic);
            message = session.createTextMessage();
            message.setStringProperty("MsgType", msgType);
            message.setText(msgText);
            System.out.println(
                    "PUBLISHER: Setting " + "message text to: "
                    + msgType);
            publisher.send(message);
        } catch (Throwable t) {
            // JMSException could be thrown
            logger.severe(
                    "PublisherBean.publishNews: " + "Exception: "
                    + t.toString());
            sc.setRollbackOnly();
        } finally {
            if (session != null) {
                try {
                    session.close();
                } catch (JMSException e) {
                }
            }
        }
    }

    /**
     * Closes the connection.
     */
    @PreDestroy
    public void endConnection() throws RuntimeException {
        if (connection != null) {
            try {
                connection.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }
}
